#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-14alewZUO34Fld7y90pmh2
key:                  dhall-1.42.3-14alewZUO34Fld7y90pmh2
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  9ce7f3d9506fd2c6cc702c336a0cf62d
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-14alewZUO34Fld7y90pmh2
depends:
    Diff-1.0-D1uS3CDE3C2D1jvzksxAXq
    aeson-2.2.2.0-7c2B0clV8yIEXobemFKLly
    aeson-pretty-0.8.11-LVNoohdI0M2IVTvPaVGDsV
    ansi-terminal-1.1-ISNPiouOT5KL4Fl392usuf
    atomic-write-0.2.1.1-BwD06caSNeLBphDiTBk986 base-4.18.2.1
    base16-bytestring-1.0.2.0-ByMCn8zKGRo9vt3g1pdMOE
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-6RlPO9Qfa9fCrnhTKB14aA
    cborg-0.2.10.0-J0pZxnT6kpEH4piY141txc
    cborg-json-0.2.6.0-BgpYHrkY4OeEUt1B5t3GDt containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-K9jvshHexe3EoFTfvx5JGo
    data-fix-0.3.4-HsJKCAPAT1hFJCcsZJWqDT deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-DAFixdA0EjEqx9uv0mesY exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-7Pe1x9OfmqnD6mFPUnyuYB
    hashable-1.4.7.0-Eia1GH7GKUH7V9HVPMehAJ haskeline-0.8.2.1
    http-client-0.7.19-8AzWSyA06XNDCM9FIBhhTj
    http-client-tls-0.3.6.4-BvllTDsMTKuIzBrdJiMfMj
    http-types-0.12.4-AW38QdPURmwEzxajknpV4M
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    megaparsec-9.7.1-JXz5wEb4OUx5fCiSnZpt43
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-FHtb4mND2mdHJ6uOX3EAJs
    optparse-applicative-0.18.1.0-1GwAi5PB1hADJzugBCuEN1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-D7shp3d6RKdFgdGi67JG8R
    pretty-simple-4.1.4.0-DaBMFhchWdM2C8tPrUwFfa
    prettyprinter-1.7.2-IAT1Mz24wwt4xYlQDqw7Fl
    prettyprinter-ansi-terminal-1.1.4-9lKjnnenLfpH5FphOKax00
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-A5wXYZ7oCLNAWLoDifRRUz
    serialise-0.2.6.1-LqjdX5q4UlnDRWM6cBJW84 template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-9tLQGj8Koq6ypJGis7Exm
    text-short-0.1.6.1-LDbCEoAojljLvWOKBmiM5s
    th-lift-instances-0.1.20-Bq9aYIKvq5OBANCk0dJAeR time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-E62UhAn4Tax94mss4RlSjH
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

